===============================================
Pyndl - Naive Discriminative Learning in Python
===============================================

.. image:: https://travis-ci.com/quantling/pyndl.svg?branch=master
    :target: https://travis-ci.com/quantling/pyndl

.. image:: https://coveralls.io/repos/github/quantling/pyndl/badge.svg?branch=master
    :target: https://coveralls.io/github/quantling/pyndl?branch=master

.. image:: https://img.shields.io/lgtm/grade/python/g/quantling/pyndl.svg?logo=lgtm&logoWidth=18
    :target: https://lgtm.com/projects/g/quantling/pyndl/context:python

.. image:: https://img.shields.io/pypi/pyversions/pyndl.svg
    :target: https://pypi.python.org/pypi/pyndl/

.. image:: https://img.shields.io/github/license/quantling/pyndl.svg
    :target: https://github.com/quantling/pyndl/blob/master/LICENSE.txt

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.597964.svg
   :target: https://doi.org/10.5281/zenodo.597964

*pyndl* is an implementation of Naive Discriminative Learning in Python. It was
created to analyse huge amounts of text file corpora. Especially, it allows to
efficiently apply the Rescorla-Wagner learning rule to these corpora.


Installation
============

The easiest way to install *pyndl* is using
`pip <https://pip.pypa.io/en/stable/>`_:

.. code:: bash

    pip install --user pyndl

For more information have a look at the `Installation Guide
<http://pyndl.readthedocs.io/en/latest/installation.html>`_.


Documentation
=============

*pyndl* uses ``sphinx`` to create a documentation manual. The documentation is
hosted on `Read the Docs <http://pyndl.readthedocs.io/en/latest/>`_.


Getting involved
================

The *pyndl* project welcomes help in the following ways:

* Making Pull Requests for
  `code <https://github.com/quantling/pyndl/tree/master/pyndl>`_,
  `tests <https://github.com/quantling/pyndl/tree/master/tests>`_
  or `documentation <https://github.com/quantling/pyndl/tree/master/doc>`_.
* Commenting on `open issues <https://github.com/quantling/pyndl/issues>`_
  and `pull requests <https://github.com/quantling/pyndl/pulls>`_.
* Helping to answer `questions in the issue section
  <https://github.com/quantling/pyndl/labels/question>`_.
* Creating feature requests or adding bug reports in the `issue section
  <https://github.com/quantling/pyndl/issues/new>`_.

For more information on how to contribute to *pyndl* have a look at the
`development section <http://pyndl.readthedocs.io/en/latest/development.html>`_.


Authors and Contributers
========================

*pyndl* was mainly developed by
`Konstantin Sering <https://github.com/derNarr>`_,
`Marc Weitz <https://github.com/trybnetic>`_,
`David-Elias Künstle <https://github.com/dekuenstle/>`_
and `Lennart Schneider <https://github.com/sumny>`_. For the full list of
contributers have a look at `Github's Contributor summary
<https://github.com/quantling/pyndl/contributors>`_.

Currently, it is maintained by `Konstantin Sering <https://github.com/derNarr>`_
and `Marc Weitz <https://github.com/trybnetic>`_.


Acknowledgments
===============
This research was supported by an ERC advanced Grant (no. 742545) and by the
Alexander von Humboldt Professorship awarded to R. H. Baayen and by the
University of Tübingen.

